@@ -59,7 +59,11 @@ class HandlerMessage(Thread):
         LOG_SERV.debug('Создание сокета сервера')
         serv_sock = socket(AF_INET, SOCK_STREAM)
         self.serv_sock = serv_sock
-        self.serv_sock.bind((self.serv_host, self.serv_port))
+        try:
+            self.serv_sock.bind((self.serv_host, self.serv_port))
+        except OSError as e:
+            LOG_SERV.warning(f'Неудачная попытка привязки сокета: {e}')
+            time.sleep(1)
         LOG_SERV.debug(
             f'Привязка сокета к IP адресу: {self.serv_host} и порту машины:'
             f' {self.serv_port}')
